@@ -22,18 +22,18 @@ def main():
     logger.info("Podcast Overview= {}", json.dumps(overview, indent=4))
 
     # Fetch trends for all episodes
-    # end = dt.datetime.now()
-    # start = dt.datetime.now() - dt.timedelta(days=7)
-    # trends = connector.trends(start, end)
-    # logger.info("Trends= {}", json.dumps(trends, indent=4))
+    end = dt.datetime.now()
+    start = dt.datetime.now() - dt.timedelta(days=7)
+    trends = connector.trends(start, end)
+    logger.info("Trends= {}", json.dumps(trends, indent=4))
 
     # Fetch podcast episodes
-    # episodes = connector.episodes()
-    # logger.info("Podcast Episodes= {}", json.dumps(episodes, indent=4))
+    episodes = connector.episodes()
+    logger.info("Podcast Episodes= {}", json.dumps(episodes, indent=4))
 
     # Fetch metadata for single podcast episode
-    # episode = connector.episode("1000581490950")
-    # logger.info("Podcast Episode= {}", json.dumps(episode, indent=4))
+    episode = connector.episode("1000581490950")
+    logger.info("Podcast Episode= {}", json.dumps(episode, indent=4))
 
 if __name__ == "__main__":
     main()
